# -*- coding: utf-8 -*-
from django.shortcuts import render, HttpResponseRedirect
from django.http import HttpRequest, HttpResponse
from django.contrib.auth import authenticate, login, logout
from django.template.exceptions import TemplateDoesNotExist, TemplateSyntaxError
from rosmorport_tsts.models import TbPetsClones



def index(request: HttpRequest) -> HttpResponse:
    """ тест индексной страницы

    :param
    :return response: исходящий http-ответ
    """
    # try:
    #     return render(request, "index.jinja", {})
    # except (TemplateDoesNotExist, TemplateSyntaxError) as e:
    #     # Обработка ошибки отсутствия шаблона
    #     return HttpResponse(f"Не нашли шаблон или в нем ошибка \"{e}\".", status=424)
    return render(request, template_name="index.jinja", context={})


def my_logout(request: HttpRequest) -> HttpResponseRedirect:
    """ Разлогируем пользователя

    :param
    :return response: исходящий http-ответ
    """
    logout(request)
    return HttpResponseRedirect(redirect_to='/')


def my_login(request: HttpRequest) -> HttpResponseRedirect:
    """ Логиним пользователя

    :param
    :return response: исходящий http-ответ
    """
    try:
        if request.method == 'POST':
            user = authenticate(request,
                                username=request.POST['username'],
                                password=request.POST['password'])
            if user is None:
                return HttpResponseRedirect(redirect_to='/not-auth')
            else:
                login(request, user)
        return HttpResponseRedirect('/')
    except KeyError:
        return HttpResponseRedirect('/')


def not_auth(request: HttpRequest) -> HttpResponse:
    """ Страница для неавторизованных пользователей

    :param
    :return response: исходящий http-ответ
    """
    to_template = {"META_REFRESH": "15; url=/"}
    return render(request, template_name="not_auth.jinja", context=to_template, status=401)


def add_clone(request: HttpRequest) -> HttpResponse:
    """ Добавление клонированного питомца

    :param
    :return response: исходящий http-ответ
    """
    to_template = {
        "META_REFRESH": "600; url=/logout",    # автоматический logout через 10 минут бездействия
        "PET_TYPES": TbPetsClones.PetType.choices,
        "PET_SEXES": TbPetsClones.PetSex.choices
    }
    return render(request, template_name="input_data.jinja", context=to_template)


def save_clone(request: HttpRequest) -> HttpResponse:
    """ Сохранение записи о клонированном питомце

    :param
    :return response: исходящий http-ответ
    """
    to_template = {
        "META_REFRESH": "2; url=/add-clone",  # автоматическое перенаправление на новую регистрацию через 2 секунды
    }
    if request.method == 'POST':
        try:
            pay = request.POST.get('pay')
            pet_type = request.POST.get('type')
            pet_sex = request.POST.get('sex')
            pet_is_alive = True if 'is-alive' in request.POST else False
            pet_reg = False if 'noreg' in request.POST else True
            pet_name = request.POST.get('name')
            pet_note = request.POST.get('note')
            pet_owner = None if request.POST.get('owner') == "" else request.POST.get('owner')
            pet = TbPetsClones(
                iPetType=int(pet_type),
                szPetName=pet_name,
                iPetSex=int(pet_sex),
                bPetIsAlive=pet_is_alive,
                szPetOwner=pet_owner,
                szPetPrice=int(pay),
                szPetComment=pet_note,
                bPetIsReg=pet_reg
            )
            pet.save()

        except (KeyError, ValueError, TypeError):
            return HttpResponseRedirect('/add-clone')
    return render(request, template_name="save_data.jinja", context=to_template)

